API Documentation
=================

.. toctree::
   :maxdepth: 2

   Table of Contents <self>
   creation
   dataframe
   sql
   expressions
   schema
   datatype
   groupby
   udf
   series
   configs
   misc
